pub struct HostName { /* private fields */ }Expand description
Host name, limited to 255 characters.
Commonly it is valid utf-8 string, but due to potential encoding differences, it is possible
that name cannot be interpreted as utf-8 string.
In this case user is encouraged to use as_bytes method and perform conversion by himself.
fmt
-
Debugtrait outputs byte content. -
Displaytrait outputs content as string, if possible, otherwise fallbacks to byte slice.
Implementations